DATABASES = {
	'default': {
		'ENGINE': 'django.db.backends.sqlite3',
		'NAME': ':memory:',
	},
}
SECRET_KEY = 'this_is_a_test_secret_key'
INSTALLED_APPS = ['bootstrap_components']
MIDDLEWARE_CLASSES = []



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class BootstrapComponentsConfig(AppConfig):
	"""
	Configuration entry point for the bootstrap_components app
	"""
	label = name = 'bootstrap_components'
	verbose_name = _('Bootstrap Components App')
